import { ConstructName, State, Info } from 'mdast-util-to-markdown';
import { Extension } from 'mdast-util-from-markdown';
import { Highlight, Parent as Parent$1 } from 'mdast';

/**
 * Extension for `mdast-util-from-markdown` to enable mark highlight.
 *
 * @type {FromMarkdownExtension}
 */
declare const highlightMarkFromMarkdown: Extension;
/**
 * Extension for `mdast-util-to-markdown` to enable mark highlight.
 */
declare const highlightMarkToMarkdown: {
    unsafe: {
        character: string;
        inConstruct: string;
        notInConstruct: ConstructName[];
    }[];
    handlers: {
        highlight: typeof handleMark;
    };
};
declare function handleMark(node: Highlight, _: Parent$1, state: State, info: Info): string;
declare namespace handleMark {
    var peek: typeof peekMark;
}
declare function peekMark(): string;

declare module 'mdast-util-to-markdown' {
    interface ConstructNameMap {
        /**
         * Whole m.
         *
         * ```markdown
         * > | ==a==
         *     ^^^^^
         * ```
         */
        highlight: 'highlight';
    }
}
declare module 'mdast' {
    interface Highlight extends Parent {
        type: 'highlight';
        children: PhrasingContent[];
    }
    interface StaticPhrasingContentMap {
        highlight: Highlight;
    }
    interface PhrasingContentMap {
        highlight: Highlight;
    }
    interface RootContentMap {
        highlight: Highlight;
    }
}

export { highlightMarkFromMarkdown, highlightMarkToMarkdown };
